Index: gtk2_ardour/editor_mouse.cc
===================================================================
--- gtk2_ardour/editor_mouse.cc	(revision 1552)
+++ gtk2_ardour/editor_mouse.cc	(working copy)
@@ -290,7 +290,7 @@
 {
 	bool commit = false;
 
 	/* in object/audition/timefx mode, any button press sets
 	   the selection if the object can be selected. this is a
 	   bit of hack, because we want to avoid this if the
 	   mouse operation is a region alignment.
@@ -301,6 +301,7 @@
 	if (((mouse_mode != MouseObject) &&
 	     (mouse_mode != MouseAudition || item_type != RegionItem) &&
 	     (mouse_mode != MouseTimeFX || item_type != RegionItem) &&
+	     (mouse_mode != MouseGain) &&
 	     (mouse_mode != MouseRange)) ||
 
 	    (event->type != GDK_BUTTON_PRESS && event->type != GDK_BUTTON_RELEASE || event->button.button > 3)) {
@@ -319,7 +320,7 @@
 			}
 		}
 	}
-	    
+
 	Selection::Operation op = Keyboard::selection_type (event->button.state);
 	bool press = (event->type == GDK_BUTTON_PRESS);
 
@@ -290,7 +290,7 @@
 	bool commit = false;
 
-	/* in object/audition/timefx mode, any button press sets
+	/* in object/audition/timefx/gain-automation mode, any button press sets
 	   the selection if the object can be selected. this is a
 	   bit of hack, because we want to avoid this if the
